@@ -436,7 +436,7 @@ class Raster(object):
         transform = Affine.translation(x00, y00)*Affine.scale(
                                                        cellsize, -cellsize)
         if output_file is None:
-            filename = os.path.join('tmp', 'new.tif')
+            filename = 'temp.tif'
         else:
             if output_file.endswith('.tif'):
                 filename = output_file
@@ -477,7 +477,7 @@ class Raster(object):
         kwargs.update({'crs': dst_crs, 'transform': transform, 'width': width,
                        'height': height, 'nodata':self.header['NODATA_value']})
         if output_file is None:
-            filename = os.path.join('tmp', 'new.tif')
+            filename = 'temp.tif'
         else:
             if output_file.endswith('.tif'):
                 filename = output_file
